Index: trunk/MagicSoft/Mars/manalysis/MHPedestalPix.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MHPedestalPix.cc	(revision 4904)
+++ trunk/MagicSoft/Mars/manalysis/MHPedestalPix.cc	(revision 4905)
@@ -36,5 +36,5 @@
 // - Sigma Pedestal Error / slice = Sigma Pedestal Error / Sqrt (Number slices)
 // 
-//  Derives from MHGausEvents, fits the pedestals to a Gaussian and performs
+//  Derives from MHCalibrationPix, fits the pedestals to a Gaussian and performs
 //  a Fourier analysis.
 //

Index: trunk/MagicSoft/Mars/manalysis/MHPedestalCam.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MHPedestalCam.cc	(revision 4904)
+++ trunk/MagicSoft/Mars/manalysis/MHPedestalCam.cc	(revision 4905)
@@ -29,5 +29,5 @@
 //
 // Fills the extracted pedestals of MExtractedSignalCam into
 // the MHGausEvents-classes MHPedestalPix for every:
 //
 // - Pixel, stored in the TObjArray's MHCalibrationCam::fHiGainArray
@@ -55,10 +55,10 @@
 // the fit is declared valid.
 // Otherwise, the fit is repeated within ranges of the previous mean
 // +- MHGausEvents::fPickupLimit (default: 5) sigma (see MHGausEvents::RepeatFit())
 // In case this does not make the fit valid, the histogram means and RMS's are
 // taken directly (see MHGausEvents::BypassFit()).
 //
 // Outliers of more than MHGausEvents::fPickupLimit (default: 5) sigmas
 // from the mean are counted as Pickup events (stored in MHGausEvents::fPickup)
 //
 // The number of summed FADC slices is taken to re-normalize
@@ -341,10 +341,10 @@
 //
 // If MBadPixelsPix::IsBad():
-// - calls MHGausEvents::SetExcluded()
+// - calls MHCalibrationPix::SetExcluded()
 //
 // Calls:
 // - MHGausEvents::InitBins()
-// - MHGausEvents::ChangeHistId(i)
-// - MHGausEvents::SetEventFrequency(fPulserFrequency)
+// - MHCalibrationPix::ChangeHistId(i)
+// - MHCalibrationPix::SetEventFrequency(fPulserFrequency)
 // - MHPedestalPix::SetNSlices(nslices)
 //
@@ -401,6 +401,6 @@
   for (UInt_t i=0; i<npixels; i++)
   {
-      MHGausEvents &histhi = (*this)[i];
-      MHGausEvents &histlo = (*this)(i);
+      MHCalibrationPix &histhi = (*this)[i];
+      MHCalibrationPix &histlo = (*this)(i);
 
       if (histhi.IsExcluded())
@@ -431,8 +431,8 @@
   for (UInt_t j=0; j<nareas; j++)
     {
-      MHGausEvents &histhi = GetAverageHiGainArea(j);
+      MHCalibrationPix &histhi = GetAverageHiGainArea(j);
       histhi.FillHistAndArray(numareahi[j] == 0 ? 0. : sumareahi[j]/numareahi[j]);
 
-      MHGausEvents &histlo = GetAverageLoGainArea(j);
+      MHCalibrationPix &histlo = GetAverageLoGainArea(j);
       histlo.FillHistAndArray(numarealo[j] == 0 ? 0. : sumarealo[j]/numarealo[j]);
     }
@@ -440,8 +440,8 @@
   for (UInt_t j=0; j<nsectors; j++)
     {
-      MHGausEvents &histhi = GetAverageHiGainSector(j);
+      MHCalibrationPix &histhi = GetAverageHiGainSector(j);
       histhi.FillHistAndArray(numsectorhi[j] == 0 ? 0. : sumsectorhi[j]/numsectorhi[j]);
 
-      MHGausEvents &histlo = GetAverageLoGainSector(j);
+      MHCalibrationPix &histlo = GetAverageLoGainSector(j);
       histlo.FillHistAndArray(numsectorlo[j] == 0 ? 0. : sumsectorlo[j]/numsectorlo[j]);
     }
@@ -29,5 +29,5 @@
 //
 // Fills the extracted pedestals of MExtractedSignalCam into
-// the MHGausEvents-classes MHPedestalPix for every:
+// the MHCalibrationPix-classes MHPedestalPix for every:
 //
 // - Pixel, stored in the TObjArray's MHCalibrationCam::fHiGainArray
@@ -55,10 +55,10 @@
 // the fit is declared valid.
 // Otherwise, the fit is repeated within ranges of the previous mean
-// +- MHGausEvents::fPickupLimit (default: 5) sigma (see MHGausEvents::RepeatFit())
+// +- MHCalibrationPix::fPickupLimit (default: 5) sigma (see MHCalibrationPix::RepeatFit())
 // In case this does not make the fit valid, the histogram means and RMS's are
@@ -55,10 +55,10 @@
 // In case this does not make the fit valid, the histogram means and RMS's are
-// taken directly (see MHGausEvents::BypassFit()).
-//
-// Outliers of more than MHGausEvents::fPickupLimit (default: 5) sigmas
-// from the mean are counted as Pickup events (stored in MHGausEvents::fPickup)
+// taken directly (see MHCalibrationPix::BypassFit()).
+//
+// Outliers of more than MHCalibrationPix::fPickupLimit (default: 5) sigmas
+// from the mean are counted as Pickup events (stored in MHCalibrationPix::fPickup)
 //
 // The number of summed FADC slices is taken to re-normalize